#!/bin/sh

# This file is part of MADDE
#
# Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
#
# Contact: Juha Riihimäki <juha.riihimaki@nokia.com>
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# version 2.1 as published by the Free Software Foundation.
#
# This library is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110-1301 USA

# this script make sure developer stuff is there, no matter in whose
# permissions the final binary is run.

set -eu
#exec 2>> /tmp/maddev-start.log; date >&2; set -x; : "$@"

libdir=/usr/lib/sdk-connectivity-tool    #mad-developer

#LC_ALL=C LANG=C
#export LC_ALL LANG
#PATH=$libdir/bin:$DEVELOPER_HOME/bin:/bin:/sbin:/usr/bin:/usr/sbin
PATH=/bin:/sbin:/usr/bin:/usr/sbin
export PATH

DEVELOPER_HOME=`awk -F: '$1 == "developer" { print $6 }' /etc/passwd`
case $DEVELOPER_HOME in '') echo 'No developer user' >&2; exit 1 ;; esac
export DEVELOPER_HOME

devown ()
{
	# busybox ls do not support -H, let's not make HOME symlink...
	# ... and busybox stat unusable.
	case `LC_ALL=C ls -ld "$1" | awk '{print $3}'` in user|develop*) ;;
		*) chown -h developer:developer "$1" ;;
	esac
}

mkdevdir ()
{
    test -d "$1" || mkdir -m 755 "$1"
    devown "$1"
}

mkdevdir $DEVELOPER_HOME

test -f $DEVELOPER_HOME/.profile || cp $libdir/dot-profile $DEVELOPER_HOME/.profile
devown $DEVELOPER_HOME/.profile

# Share user MyDocs -- FAT32 permissions 777 on N900
test -d $DEVELOPER_HOME/MyDocs || {
	if test -d /home/user/MyDocs
	then (
		mmksln () { test ! $1 "$2" -o $1 "$3" || {
				rm -f "$3"; ln -s "$2" "$3"; devown "$3"; }
		}
		cd $DEVELOPER_HOME
		mmksln -d /home/user/MyDocs MyDocs
		#mmksln -d /home/user/.config .config
		mkdevdir .config
		mmksln -f /home/user/.config/user-dirs.dirs .config/user-dirs.dirs
		mkdevdir .cache
		#mkdevdir .local
		#mkdevdir .local/share
		#mkdevdir .local/share/data
	); fi
}

mkdevdir $DEVELOPER_HOME/bin

test -f $DEVELOPER_HOME/bin/remote-wrapper.sh || {
	rm -f $DEVELOPER_HOME/bin/remote-wrapper.sh || :
	ln -s $libdir/bin/remote-wrapper.sh $DEVELOPER_HOME/bin
}

#case $1 in cd) cd "$2"; shift 2;; esac # removed for security reasons.

case $1 in --cdbin) shift 1; cd "$libdir/bin" ;; esac

case $1 in -*) echo "'$1' cannot start with '-'" >&2; exit 1 ;; esac

exec /usr/bin/aegis-exec -u user "$@"
exit

# The busybox su (and devel-su) (unexpectly!) both reset wd.
cdir=`pwd`
exec su -p user -c "cd '$cdir' && exec $*"
